==> khroma_1.7.0.tar.gz: khroma/inst/doc/crameri.R <==
## ---- include=FALSE-----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
 fig.align = "center"
)

## ----setup--------------------------------------------------------------------
library(khroma)

## ----crameri_div_broc, fig.height=2, fig.width=7------------------------------
broc <- colour("broc")
plot(broc(256))

## ----crameri_div_cork, fig.height=2, fig.width=7------------------------------
cork <- colour("cork")
plot(cork(256))

## ----crameri_div_vik, fig.height=2, fig.width=7-------------------------------
vik <- colour("vik")
plot(vik(256))

## ----crameri_div_lisbon, fig.height=2, fig.width=7----------------------------
lisbon <- colour("lisbon")
plot(lisbon(256))

## ----crameri_div_tofino, fig.height=2, fig.width=7----------------------------
tofino <- colour("tofino")
plot(tofino(256))

## ----crameri_div_berlin, fig.height=2, fig.width=7----------------------------
berlin <- colour("berlin")
plot(berlin(256))

## ----crameri_div_roma, fig.height=2, fig.width=7------------------------------
roma <- colour("roma")
plot(roma(256))

## ----crameri_div_bam, fig.height=2, fig.width=7-------------------------------
bam <- colour("bam")
plot(bam(256))

## ----crameri_div_vanimo, fig.height=2, fig.width=7----------------------------
vanimo <- colour("vanimo")
plot(vanimo(256))

## ----crameri_seq_batlow, fig.height=2, fig.width=7----------------------------
batlow <- colour("batlow")
plot(batlow(256))

## ----crameri_seq_batlowW, fig.height=2, fig.width=7---------------------------
batlowW <- colour("batlowW")
plot(batlowW(256))

## ----crameri_seq_batlowK, fig.height=2, fig.width=7---------------------------
batlowK <- colour("batlowK")
plot(batlowK(256))

## ----crameri_seq_devon, fig.height=2, fig.width=7-----------------------------
devon <- colour("devon")
plot(devon(256))

## ----crameri_seq_lajolla, fig.height=2, fig.width=7---------------------------
lajolla <- colour("lajolla")
plot(lajolla(256))

## ----crameri_seq_bamako, fig.height=2, fig.width=7----------------------------
bamako <- colour("bamako")
plot(bamako(256))

## ----crameri_seq_davos, fig.height=2, fig.width=7-----------------------------
davos <- colour("davos")
plot(davos(256))

## ----crameri_seq_bilbao, fig.height=2, fig.width=7----------------------------
bilbao <- colour("bilbao")
plot(bilbao(256))

## ----crameri_seq_nuuk, fig.height=2, fig.width=7------------------------------
nuuk <- colour("nuuk")
plot(nuuk(256))

## ----crameri_seq_oslo, fig.height=2, fig.width=7------------------------------
oslo <- colour("oslo")
plot(oslo(256))

## ----crameri_seq_grayC, fig.height=2, fig.width=7-----------------------------
grayC <- colour("grayC")
plot(grayC(256))

## ----crameri_seq_hawaii, fig.height=2, fig.width=7----------------------------
hawaii <- colour("hawaii")
plot(hawaii(256))

## ----crameri_seq_lapaz, fig.height=2, fig.width=7-----------------------------
lapaz <- colour("lapaz")
plot(lapaz(256))

## ----crameri_seq_tokyo, fig.height=2, fig.width=7-----------------------------
tokyo <- colour("tokyo")
plot(tokyo(256))

## ----crameri_seq_buda, fig.height=2, fig.width=7------------------------------
buda <- colour("buda")
plot(buda(256))

## ----crameri_seq_acton, fig.height=2, fig.width=7-----------------------------
acton <- colour("acton")
plot(acton(256))

## ----crameri_seq_turku, fig.height=2, fig.width=7-----------------------------
turku <- colour("turku")
plot(turku(256))

## ----crameri_seq_imola, fig.height=2, fig.width=7-----------------------------
imola <- colour("imola")
plot(imola(256))

## ----crameri_seq_oleron, fig.height=2, fig.width=7----------------------------
oleron <- colour("oleron")
plot(oleron(256))

## ----crameri_seq_bukavu, fig.height=2, fig.width=7----------------------------
bukavu <- colour("bukavu")
plot(bukavu(256))

## ----crameri_seq_fes, fig.height=2, fig.width=7-------------------------------
fes <- colour("fes")
plot(fes(256))

==> khroma_1.8.0.tar.gz: khroma/inst/doc/crameri.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = "center"
)

## ----packages-----------------------------------------------------------------
library(khroma)

## ----crameri_div_broc, fig.height=2, fig.width=7------------------------------
broc <- colour("broc")
plot(broc(256))

## ----crameri_div_cork, fig.height=2, fig.width=7------------------------------
cork <- colour("cork")
plot(cork(256))

## ----crameri_div_vik, fig.height=2, fig.width=7-------------------------------
vik <- colour("vik")
plot(vik(256))

## ----crameri_div_lisbon, fig.height=2, fig.width=7----------------------------
lisbon <- colour("lisbon")
plot(lisbon(256))

## ----crameri_div_tofino, fig.height=2, fig.width=7----------------------------
tofino <- colour("tofino")
plot(tofino(256))

## ----crameri_div_berlin, fig.height=2, fig.width=7----------------------------
berlin <- colour("berlin")
plot(berlin(256))

## ----crameri_div_roma, fig.height=2, fig.width=7------------------------------
roma <- colour("roma")
plot(roma(256))

## ----crameri_div_bam, fig.height=2, fig.width=7-------------------------------
bam <- colour("bam")
plot(bam(256))

## ----crameri_div_vanimo, fig.height=2, fig.width=7----------------------------
vanimo <- colour("vanimo")
plot(vanimo(256))

## ----crameri_seq_batlow, fig.height=2, fig.width=7----------------------------
batlow <- colour("batlow")
plot(batlow(256))

## ----crameri_seq_batlowW, fig.height=2, fig.width=7---------------------------
batlowW <- colour("batlowW")
plot(batlowW(256))

## ----crameri_seq_batlowK, fig.height=2, fig.width=7---------------------------
batlowK <- colour("batlowK")
plot(batlowK(256))

## ----crameri_seq_devon, fig.height=2, fig.width=7-----------------------------
devon <- colour("devon")
plot(devon(256))

## ----crameri_seq_lajolla, fig.height=2, fig.width=7---------------------------
lajolla <- colour("lajolla")
plot(lajolla(256))

## ----crameri_seq_bamako, fig.height=2, fig.width=7----------------------------
bamako <- colour("bamako")
plot(bamako(256))

## ----crameri_seq_davos, fig.height=2, fig.width=7-----------------------------
davos <- colour("davos")
plot(davos(256))

## ----crameri_seq_bilbao, fig.height=2, fig.width=7----------------------------
bilbao <- colour("bilbao")
plot(bilbao(256))

## ----crameri_seq_nuuk, fig.height=2, fig.width=7------------------------------
nuuk <- colour("nuuk")
plot(nuuk(256))

## ----crameri_seq_oslo, fig.height=2, fig.width=7------------------------------
oslo <- colour("oslo")
plot(oslo(256))

## ----crameri_seq_grayC, fig.height=2, fig.width=7-----------------------------
grayC <- colour("grayC")
plot(grayC(256))

## ----crameri_seq_hawaii, fig.height=2, fig.width=7----------------------------
hawaii <- colour("hawaii")
plot(hawaii(256))

## ----crameri_seq_lapaz, fig.height=2, fig.width=7-----------------------------
lapaz <- colour("lapaz")
plot(lapaz(256))

## ----crameri_seq_tokyo, fig.height=2, fig.width=7-----------------------------
tokyo <- colour("tokyo")
plot(tokyo(256))

## ----crameri_seq_buda, fig.height=2, fig.width=7------------------------------
buda <- colour("buda")
plot(buda(256))

## ----crameri_seq_acton, fig.height=2, fig.width=7-----------------------------
acton <- colour("acton")
plot(acton(256))

## ----crameri_seq_turku, fig.height=2, fig.width=7-----------------------------
turku <- colour("turku")
plot(turku(256))

## ----crameri_seq_imola, fig.height=2, fig.width=7-----------------------------
imola <- colour("imola")
plot(imola(256))

## ----crameri_seq_oleron, fig.height=2, fig.width=7----------------------------
oleron <- colour("oleron")
plot(oleron(256))

## ----crameri_seq_bukavu, fig.height=2, fig.width=7----------------------------
bukavu <- colour("bukavu")
plot(bukavu(256))

## ----crameri_seq_fes, fig.height=2, fig.width=7-------------------------------
fes <- colour("fes")
plot(fes(256))
